@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 from functools import lru_cache
-from sys import intern
 from typing import TYPE_CHECKING, Callable, Iterable, Sequence
 
 import rich.repr
@@ -14,7 +13,7 @@ from textual._ansi_theme import DEFAULT_TERMINAL_THEME
 from textual._border import get_box, render_border_label, render_row
 from textual._context import active_app
 from textual._opacity import _apply_opacity
-from textual._segment_tools import apply_hatch, line_pad, line_trim
+from textual._segment_tools import apply_hatch, line_pad, line_trim, make_blank
 from textual.color import TRANSPARENT, Color
 from textual.constants import DEBUG
 from textual.content import Content
@@ -34,20 +33,6 @@ if TYPE_CHECKING:
 RenderLineCallback: TypeAlias = Callable[[int], Strip]
 
 
-@lru_cache(1024 * 8)
-def make_blank(width, style: RichStyle) -> Segment:
-    """Make a blank segment.
-
-    Args:
-        width: Width of blank.
-        style: Style of blank.
-
-    Returns:
-        A single segment
-    """
-    return Segment(intern(" " * width), style)
-
-
 @rich.repr.auto(angular=True)
 class StylesCache:
     """Responsible for rendering CSS Styles and keeping a cache of rendered lines.
@@ -105,6 +90,7 @@ class StylesCache:
 
     def clear(self) -> None:
         """Clear the styles cache (will cause the content to re-render)."""
+
         self._cache.clear()
         self._dirty_lines.clear()
 
@@ -118,11 +104,10 @@ class StylesCache:
         Returns:
             Rendered lines.
         """
-
         border_title = widget._border_title
         border_subtitle = widget._border_subtitle
 
-        base_background, background = widget._opacity_background_colors
+        base_background, background = widget.background_colors
         styles = widget.styles
         strips = self.render(
             styles,
@@ -130,6 +115,7 @@ class StylesCache:
             base_background,
             background,
             widget.render_line,
+            widget.get_line_filters(),
             (
                 None
                 if border_title is None
@@ -149,7 +135,6 @@ class StylesCache:
             content_size=widget.content_region.size,
             padding=styles.padding,
             crop=crop,
-            filters=widget.app._filters,
             opacity=widget.opacity,
             ansi_theme=widget.app.ansi_theme,
         )
@@ -177,12 +162,12 @@ class StylesCache:
         base_background: Color,
         background: Color,
         render_content_line: RenderLineCallback,
+        filters: Sequence[LineFilter],
         border_title: tuple[Content, Color, Color, Style] | None,
         border_subtitle: tuple[Content, Color, Color, Style] | None,
         content_size: Size | None = None,
         padding: Spacing | None = None,
         crop: Region | None = None,
-        filters: Sequence[LineFilter] | None = None,
         opacity: float = 1.0,
         ansi_theme: TerminalTheme = DEFAULT_TERMINAL_THEME,
     ) -> list[Strip]:
@@ -202,6 +187,7 @@ class StylesCache:
             crop: Region to crop to.
             filters: Additional post-processing for the segments.
             opacity: Widget opacity.
+            ansi_theme: Theme for ANSI colors.
 
         Returns:
             Rendered lines.
@@ -222,9 +208,7 @@ class StylesCache:
 
         is_dirty = self._dirty_lines.__contains__
         render_line = self.render_line
-        apply_filters = (
-            [] if filters is None else [filter for filter in filters if filter.enabled]
-        )
+
         for y in crop.line_range:
             if is_dirty(y) or y not in self._cache:
                 strip = render_line(
@@ -245,7 +229,7 @@ class StylesCache:
             else:
                 strip = self._cache[y]
 
-            for filter in apply_filters:
+            for filter in filters:
                 strip = strip.apply_filter(filter, background)
 
             if DEBUG:
@@ -262,6 +246,16 @@ class StylesCache:
 
         return strips
 
+    @lru_cache(1024)
+    def get_inner_outer(
+        cls, base_background: Color, background: Color
+    ) -> tuple[Style, Style]:
+        """Get inner and outer background colors."""
+        return (
+            Style(background=base_background + background),
+            Style(background=base_background),
+        )
+
     def render_line(
         self,
         styles: StylesBase,
@@ -318,9 +312,7 @@ class StylesCache:
         ) = styles.outline
 
         from_color = RichStyle.from_color
-
-        inner = Style(background=(base_background + background))
-        outer = Style(background=base_background)
+        inner, outer = self.get_inner_outer(base_background, background)
 
         def line_post(segments: Iterable[Segment]) -> Iterable[Segment]:
             """Apply effects to segments inside the border."""
@@ -342,7 +334,6 @@ class StylesCache:
             Returns:
                 New list of segments
             """
-
             try:
                 app = active_app.get()
                 ansi_theme = app.ansi_theme
@@ -360,7 +351,6 @@ class StylesCache:
         line: Iterable[Segment]
         # Draw top or bottom borders (A)
         if (border_top and y == 0) or (border_bottom and y == height - 1):
-
             is_top = y == 0
             border_color = base_background + (
                 border_top_color if is_top else border_bottom_color
@@ -426,7 +416,7 @@ class StylesCache:
         elif (pad_top and y < gutter.top) or (
             pad_bottom and y >= height - gutter.bottom
         ):
-            background_rich_style = from_color(bgcolor=background.rich_color)
+            background_rich_style = inner.rich_style
             left_style = Style(
                 foreground=base_background + border_left_color.multiply_alpha(opacity)
             )
@@ -449,15 +439,12 @@ class StylesCache:
             content_y = y - gutter.top
             if content_y < content_height:
                 line = render_content_line(y - gutter.top)
-                line = line.adjust_cell_length(content_width)
+                line = line.adjust_cell_length(content_width, inner.rich_style)
             else:
-                line = [make_blank(content_width, inner.rich_style)]
-            if inner:
-                line = Segment.apply_style(line, inner.rich_style)
-            if styles.text_opacity != 1.0:
-                line = TextOpacity.process_segments(
-                    line, styles.text_opacity, ansi_theme
-                )
+                line = Strip.blank(content_width, inner.rich_style)
+
+            if (text_opacity := styles.text_opacity) != 1.0:
+                line = TextOpacity.process_segments(line, text_opacity, ansi_theme)
             line = line_post(line_pad(line, pad_left, pad_right, inner.rich_style))
 
             if border_left or border_right:
