@@ -89,10 +89,10 @@ class Driver(ABC):
         else:
             offset_x, offset_y = self.cursor_origin
         if isinstance(message, events.MouseEvent):
-            message.x -= offset_x
-            message.y -= offset_y
-            message.screen_x -= offset_x
-            message.screen_y -= offset_y
+            message._x -= offset_x
+            message._y -= offset_y
+            message._screen_x -= offset_x
+            message._screen_y -= offset_y
 
         if isinstance(message, events.MouseDown):
             if message.button:
@@ -234,7 +234,7 @@ class Driver(ABC):
                 in the `Content-Type` header.
             mime_type: *web only* The MIME type of the file. This will be used to
                 set the `Content-Type` header in the HTTP response.
-            name: A user-defined named which will be returned in [`DeliveryComplete`][textual.events.DeliveryComplete]
+            name: A user-defined name which will be returned in [`DeliveryComplete`][textual.events.DeliveryComplete]
                 and [`DeliveryComplete`][textual.events.DeliveryComplete].
 
         """
